package javax.swing.plaf.synth;

import javax.swing.JColorChooser;
import java.beans.PropertyChangeEvent;
import java.awt.Graphics;
import javax.swing.colorchooser.ColorChooserComponentFactory;
import javax.swing.colorchooser.AbstractColorChooserPanel;
import javax.swing.plaf.ComponentUI;
import javax.swing.JComponent;
import java.beans.PropertyChangeListener;
import javax.swing.plaf.basic.BasicColorChooserUI;

public class SynthColorChooserUI extends BasicColorChooserUI implements PropertyChangeListener, SynthUI
{
    private SynthStyle style;
    
    public SynthColorChooserUI() {
    }
    
    public static ComponentUI createUI(JComponent component) {
        return new SynthColorChooserUI();
    }
    
    @Override
    protected AbstractColorChooserPanel[] createDefaultChoosers() {
        SynthContext context = this.getContext(this.chooser, 1);
        AbstractColorChooserPanel[] defaultChooserPanels = (AbstractColorChooserPanel[])(AbstractColorChooserPanel[])context.getStyle().get(context, "ColorChooser.panels");
        context.dispose();
        if (defaultChooserPanels == null) {
            defaultChooserPanels = ColorChooserComponentFactory.getDefaultChooserPanels();
            return defaultChooserPanels;
        }
        return defaultChooserPanels;
    }
    
    @Override
    protected void installDefaults() {
        super.installDefaults();
        this.updateStyle(this.chooser);
    }
    
    private void updateStyle(JComponent component) {
        SynthContext context = this.getContext(component, 1);
        this.style = SynthLookAndFeel.updateStyle(context, this);
        context.dispose();
    }
    
    @Override
    protected void uninstallDefaults() {
        SynthContext context = this.getContext(this.chooser, 1);
        this.style.uninstallDefaults(context);
        context.dispose();
        this.style = null;
        super.uninstallDefaults();
    }
    
    @Override
    protected void installListeners() {
        super.installListeners();
        this.chooser.addPropertyChangeListener(this);
    }
    
    @Override
    protected void uninstallListeners() {
        this.chooser.removePropertyChangeListener(this);
        super.uninstallListeners();
    }
    
    @Override
    public SynthContext getContext(JComponent component) {
        return this.getContext(component, this.getComponentState(component));
    }
    
    private SynthContext getContext(JComponent component, int n) {
        return SynthContext.getContext(component, this.style, n);
    }
    
    private int getComponentState(JComponent component) {
        return SynthLookAndFeel.getComponentState(component);
    }
    
    @Override
    public void update(Graphics graphics, JComponent component) {
        SynthContext context = this.getContext(component);
        SynthLookAndFeel.update(context, graphics);
        context.getPainter().paintColorChooserBackground(context, graphics, 0, 0, component.getWidth(), component.getHeight());
        this.paint(context, graphics);
        context.dispose();
    }
    
    @Override
    public void paint(Graphics graphics, JComponent component) {
        SynthContext context = this.getContext(component);
        this.paint(context, graphics);
        context.dispose();
    }
    
    protected void paint(SynthContext synthContext, Graphics graphics) {
    }
    
    @Override
    public void paintBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        synthContext.getPainter().paintColorChooserBorder(synthContext, graphics, n, n2, n3, n4);
    }
    
    @Override
    public void propertyChange(PropertyChangeEvent propertyChangeEvent) {
        if (SynthLookAndFeel.shouldUpdateStyle(propertyChangeEvent)) {
            this.updateStyle((JColorChooser)propertyChangeEvent.getSource());
        }
    }
}
